@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@imendio.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Author: Mikael Hallendal <micke@codefactory.se>
+ * Author: Mikael Hallendal <micke@imendio.com>
  */
 
 #ifndef __YELP_VIEW_INDEX_H__
@@ -25,7 +25,9 @@
 
 #include <gtk/gtkhpaned.h>
 #include <gtk/gtktreemodel.h>
+
 #include "yelp-section.h"
+#include "yelp-view.h"
 
 #define YELP_TYPE_VIEW_INDEX        (yelp_view_index_get_type ())
 #define YELP_VIEW_INDEX(o)          (GTK_CHECK_CAST ((o), YELP_TYPE_VIEW_INDEX, YelpViewIndex))
@@ -38,26 +40,16 @@ typedef struct _YelpViewIndexClass   YelpViewIndexClass;
 typedef struct _YelpViewIndexPriv    YelpViewIndexPriv;
 
 struct _YelpViewIndex {
-	GtkHPaned          parent;
+	YelpView           parent;
 	
 	YelpViewIndexPriv *priv;
 };
 
 struct _YelpViewIndexClass {
-        GtkHPanedClass    parent_class;
-
-	/* Signals */
-
-	void (*uri_selected)   (YelpViewIndex *view,
-				YelpURI       *uri,
-				gboolean       handled);
+        YelpViewClass      parent_class;
 };
 
 GType           yelp_view_index_get_type     (void);
-GtkWidget      *yelp_view_index_new          (GList            *index);
-
-void            yelp_view_index_show_uri     (YelpViewIndex    *view,
-					      YelpURI          *uri,
-					      GError          **error);
+YelpView *      yelp_view_index_new          (GList            *index);
 
 #endif /* __YELP_VIEW_INDEX__ */
